@@ -1,18 +1,19 @@
 ;(function(){
   var map = {
-  "commitId": "884d8c6659eac9c8b3d40634e1c4c8bd2f63adcb",
-  "branchName": "release",
-  "buildTime": "Mon, 27 Mar 2023 06:16:04 GMT",
-  "buildVersion": "322",
+  "commitId": "f9fbb1a1210e9704c0a40d64dfa655179c506ad6",
+  "branchName": "release-client-5.x",
+  "buildTime": "2023-06-17 12:13:53 GMT",
+  "buildVersion": "5.1.452",
   "css": [
-    "@zoom/client-calendar/static/css/default~app.391672d7.css",
-    "@zoom/client-calendar/static/css/vendors~app.f43a7829.css"
+    "@zoom/client-calendar/static/css/default~app.2c022cc9.css",
+    "@zoom/client-calendar/static/css/vendors~app.dc891ce4.css"
   ],
   "js": [
-    "@zoom/client-calendar/static/js/default~app.3c7fd519.js",
-    "@zoom/client-calendar/static/js/vendors~app.1f3ccfa0.js",
-    "@zoom/client-calendar/static/js/app.dfb42586.js"
-  ]
+    "@zoom/client-calendar/static/js/default~app.d2af72c2.js",
+    "@zoom/client-calendar/static/js/vendors~app.f5b33390.js",
+    "@zoom/client-calendar/static/js/app.01d92ee2.js"
+  ],
+  "key": "@zoom/client-calendar"
 };
   var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
   map.css && map.css.forEach(function (cssItem) {
